
% plots r=const slices of the universal lookup table, and then computes two
% phi = const slices using trilinear interpolation.  For the phi = 0 slice,
% Notice a large yellow "dead zone" where the smoothing factor is 1.
% Then, notice how this "dead zone" is greatly reduced in size for phi =
% pi/2.
%
% The universal lookup table is organized like this:
% Lookup(:,:,:,1) = optimal damping parameter for nu = 1,
% Lookup(:,:,:,2) = associated optimal smoothing factor for nu = 1.
% Lookup(:,:,:,3) = optimal damping parameter for nu = 2,
% Lookup(:,:,:,4) = associated optimal smoothing factor for nu = 2.
% Lookup(i,:,:,:) ~ r = const slice.
% Lookup(:,j,:,:) ~ c_m = const slice.
% Lookup(:,:,k,:) ~ phi = const slice.

clear all;

addpath SmoothingTheory

load UniversalLookup Lookup

[M,N,~,~]=size(Lookup);


% lets plot r = constant surfaces of the universal lookup table, in
% increments of 10 rows.



for k=1:M
    if mod(k,10)==0
        figure
        surf(reshape(Lookup(k,:,:,2),[N,N]),'EdgeColor','None')
        title(['r = ',num2str(2*(k-1)/(M-1)),' smoothing factor'])
        xlabel('theta')
        ylabel('c_m/c')
    end
end


% let's test the interpolation routine by making something between values.

M2 = 101;

Cm_max = 0.25;
Phi_max = pi;
R_max = 2;
h_1 = Cm_max/(M2-1);
h_2 = Phi_max/(M2-1);
h_3 = R_max/(M2-1);

% Now let's plot a few phi = const surfaces.

c_m = (0:h_1:0.25)';
r = (0:h_3:2)';

c_m = kron(ones(M2,1),c_m);
r = kron(r,ones(M2,1));
phi = zeros(M2^2,1);

f=reshape(interpolate_lookup_table(c_m,r,phi,Lookup,'mu1'),[M2,M2]);
X = reshape(c_m,[M2,M2]);
Y = reshape(r,[M2,M2]);

figure
surf(X,Y,f,'EdgeColor','None')
title('Interplated table at phi = 0')
xlabel('c_m')
ylabel('r')
set(gca,'fontsize',20,'LineWidth',2)

phi = (pi/2)*ones(M2^2,1);

f=reshape(interpolate_lookup_table(c_m,r,phi,Lookup,'mu1'),[M2,M2]);
X = reshape(c_m,[M2,M2]);
Y = reshape(r,[M2,M2]);

figure
surf(X,Y,f,'EdgeColor','None')
title('Interplated table at phi = pi/2')
xlabel('c_m')
ylabel('r')
set(gca,'fontsize',20,'LineWidth',2)

