function [vel,x,z]=marmousi_velocity(dx)
% MARMOUSI_VELOCITY: read the matlab ascii file containing the Marmousi velocity model
%
% [vel,x,z]=marmousi_velocity(dx)
%
% This function is designed to read from the matlab marmousi velocity ascii
% dataset named vel_asc_8_33m.grd . This datset must be in your current
% directory or the function will fail. Use the "pwd" command to display your
% current director and the "ls" command to list its contents.
%
% dx ... spatial grid interval for the velocity model. Specifies the
%   distance bewtween rows and between columns. Must be >= 8+1/3 (meters)
% *********** defaults to 8+1/3 *************
% vel ... matrix of velocity values (meters/sec). x varies along columns, z (depth) along rows
% x ... row vector of coordinates for the columns of vel
% z column vector of coordinates for the rows of vel
%
% G.F. Margrave, CREWES/POTSI 2004
%
 
% see if the data exists

test=which('vel_asc_8_33m.grd');
if(isempty(test))
    error('The file vel_asc_8_33m.grd does not appear in your current directory');
end

dxnom=8+1/3;

if(nargin<1) dx=dxnom; end

if(dx<dxnom)
    error('spcified grid size must be no smaller than 8+1/3');
end

%% reading the 8.33m velocity file
load -ascii vel_asc_8_33m.grd;

xv_fine=(0:size(vel_asc_8_33m,2)-1)*dxnom;
zv_fine=((0:size(vel_asc_8_33m,1)-1)*dxnom)';
if(abs(dx-dxnom)>.0001)
    vel=vdesample(vel_asc_8_33m,xv_fine,dx); %resample rows
    vel=vdesample(vel',zv_fine,dx)';%resample columns
else
    dx=dxnom;
    vel=vel_asc_8_33m;
end
clear vel_asc_8_33m;

%smooth the velocity model
wsmooth=0; %width of smoother in meters
if(wsmooth>0)
    nsmooth=round(wsmooth/dx);
    smoother=ones(nsmooth,nsmooth);
    vel=conv2(vel,smoother,'same')/(nsmooth^2);
end

[nz,nv]=size(vel);

z=dx*[0:nz-1]'; %z coordinate for velocity model
x=dx*(0:nv-1); %x coordintate for velocity model
