function u_h = FCYC(Ls,Ps,Rs,u_h,f_h,level,setup)

    
    % increment the number of times we have visited this level
    setup.levelCounts(level)=setup.levelCounts(level)+1;
    
    L_h = Ls{level};
    
    % first smoothing sweep
    for j=1:setup.nu1
        u_h=smooth(L_h,u_h,f_h,level,setup,setup.RB_stuff{level});
    end
    
    % compute residual and project down to lower grid.
    r_h = f_h - L_h*u_h;
    

    I_Hh = Rs{level};
    I_hH = Ps{level};
    
    r_H = I_Hh*r_h;
   
    N=2^(level-1)-setup.delta;
    d=setup.dimension;
    
    if ~strcmp(setup.coefficients,'Marmousi')
    
        e_H = zeros(N^d,1); % initial guess on lower grid.
        
    else
        M = 3*N+2*setup.delta;
        e_H = zeros(N*M,1);
    end
    
    % we have to scale the residual, depending on whether we are using
    % Galerkin or direct discretization.  Vertex-centered multigrid always
    % uses a direct discretization in our framework, while cell-centered
    % always used Galerkin.
    if strcmp(setup.type,'vertex-centered')
        scale = 4;
    elseif strcmp(setup.type,'cell-centered')
        scale = 1;
    end

    


    
    if level <= setup.minLevel+1
        L_H = Ls{level-1};
        e_H = L_H\(scale*r_H);
    else
        e_H = FCYC(Ls,Ps,Rs,e_H,(scale*r_H),level-1,setup);
        % if it's the first time visiting this level, go back down, but
        % then never do so again.
        if setup.levelCounts(level)==1 
            e_H = FCYC(Ls,Ps,Rs,e_H,(scale*r_H),level-1,setup);
        end
    end
    
    % prolongate error back to this grid.
    
    e_h = I_hH*e_H;
    
    u_h = u_h + e_h;
    
    % second smoothing sweep.
    
    for j=1:setup.nu2
        u_h=smooth(L_h,u_h,f_h,level,setup,setup.RB_stuff{level});
    end