function Ws = getDampingParameterMatrices(Ls,setup)

Ws={};

for l=setup.level:-1:setup.minLevel+1
    
    N = 2^l-setup.delta;
    L_h = Ls{l};
    
    h = setup.domainHeight/(N+setup.delta);
    
    if ~strcmp(setup.coefficients,'Marmousi')
        
        [A,c,c_m]=extract_matrix_entrees(L_h,N,setup);
        M = N;
        if strcmp(setup.type,'vertex-centered')
            x = h:h:1-h;
            y = x;
        elseif strcmp(setup.type,'cell-centered')
            x = h/2:h:1-h/2;
            y = x;
        end
        xM = 1;
        yM = 1;
    else
        M=3*N+2*setup.delta;
        [A,c,c_m]=extract_matrix_entrees_rect(L_h,M,N);
        if strcmp(setup.type,'vertex-centered')
            x = h:h:9-h;
            y = h:h:3-h;
        elseif strcmp(setup.type,'cell-centered')
            x = h/2:h:9-h/2;
            y = h/2:h:3-h/2;
        end
        xM = 9;
        yM = 3;
    end
    
    if strcmp(setup.smoother,'RB-SOR')
        
        % normalize c to 0.5.
        
        A = 0.5*A./c;
        c_m = 0.5*c_m./c;
        phi = atan2(imag(A),real(A));
        r = abs(A);
        
        
        if setup.nu==1
            W_vec = interpolate_lookup_table(c_m,r,phi,setup.Lookup,'omega1');
        elseif setup.nu==2
            W_vec = interpolate_lookup_table(c_m,r,phi,setup.Lookup,'omega2');
        end
        W=spdiag(W_vec);
        
    elseif strcmp(setup.smoother,'DAMPED-JACOBI')
        
        W=get_jacobi_omega_matrix(A,c,c_m);
        
    else
        
        error('invalid smoother')
        
    end
    
    Ws{l}=W;
    
    if setup.level-l<setup.dampingParameterGraphsNum
        % if the dimension is two, we really plot the whole thing.  If
        % it is three, we plot a slice through the middle.
        if setup.dimension==2
            W_surf = reshape( full(diag(W)),[N,M]);
            [X,Y]=meshgrid(x,y);
        else
            W_volume = reshape( full(diag(W)),[N,N,N]);
            [X,Y,~]=meshgrid(x,x,x);
            [X,Y,W_surf]=get_F_mid(X,Y,W_volume);
        end
        if setup.useColorWheel
            center = 1;
            isocontours = 1;
            colorWheel(X,Y,W_surf,center,isocontours)
            xlabel('x')
            ylabel('y')
            title(['level ',num2str(setup.level-l),': color wheel visualization of spatially varying damping parameter'])
        else
            figure
            surf(X,Y,real(W_surf),'EdgeColor','None')
            xlabel('x')
            ylabel('y')
            title(['level ',num2str(setup.level-l),': Real part of spatially varying damping parameter'])
            xlim([0 xM])
            ylim([0 yM])
            set(gca,'fontsize',20,'LineWidth',2)
            figure
            surf(X,Y,imag(W_surf),'EdgeColor','None')
            xlabel('x')
            ylabel('y')
            title(['level ',num2str(setup.level-l),': Imaginary part of spatially varying damping parameter'])
            xlim([0 xM])
            ylim([0 yM])
            set(gca,'fontsize',20,'LineWidth',2)
        end
    end
    
end