function [L_2,L_0] = getL_variable(setup,level)

    N = 2^level-setup.delta;

    h = 1/(N+setup.delta);

    if strcmp(setup.type,'cell-centered')
        x = (h/2:h:1-h/2)';
    else
        x = h:h:1-h;
    end
    
    d = setup.dimension;

    % first we build the 2nd order part of the discretization (for
    % cell-centered multigrid, we need them separated as they are scaled
    % separately in the galerkin coarse grid operator)

    S = sparse(-2*eye(N)+diag(ones(N-1,1),1)+diag(ones(N-1,1),-1));

    epsilon = setup.epsilon;
    
    if d==2
        
        % implements -a(x,y)*u_xx-b(x,y)*u_yy
        
        [X,Y]=meshgrid(x);
        x = reshape(X,[N^d,1]);
        y = reshape(Y,[N^d,1]);
        Uxx = kron(S,speye(N));
        Uyy = kron(speye(N),S);
        
        a = eval(setup.a);
        b = eval(setup.b);

        
        if min(a)<=0 || min(b)<=0
            error('a(x,y) and b(x,y) must be strictly positive')
        end
        
        A = spdiag(a);
        B = spdiag(b);
        L_2 = -A*Uxx-B*Uyy;

    elseif d==3
        
        % implements -a(x,y,z)*u_xx-b(x,y,z)*u_yy-c(x,y,z)*u_zz
        
        [X,Y,Z]=meshgrid(x);
        x = reshape(X,[N^d,1]);
        y = reshape(Y,[N^d,1]);
        z = reshape(Z,[N^d,1]);
        Uxx = kron(S,kron(speye(N),speye(N)));
        Uyy = kron(speye(N),kron(S,speye(N)));
        Uzz = kron(speye(N),kron(speye(N),S));
        
        a = eval(setup.a);
        b = eval(setup.b);
        c = eval(setup.c);
        
        if min(a)<=0 || min(b)<=0 || min(c)<=0
            error('a(x,y,z), b(x,y,z) and c(x,y,z) must be strictly positive')
        end
        
        A = spdiag(a);
        B = spdiag(b);
        C = spdiag(c);
        L_2 = -A*Uxx-B*Uyy-C*Uzz;
        
    else
        
        error('invalid dimension')
        
    end
    
    % the 0th order part of the discretization
    
    L_0 = -speye(N^d)*(setup.K*h)^2*(1-1i*setup.alpha);
    

end