function [Ls,Ps,Rs]=getOperators(setup)

    topLevel = setup.level;
    minLevel = setup.minLevel;

    Ls={};
    Ps={};
    Rs={};
    
    d = setup.dimension;
    epsilon = setup.epsilon;
    % descend from the topLevel to the bottom level
    
%     if strcmp(setup.coefficients,'Marmousi') && d==2
%       N = 2^topLevel-setup.delta;
%       M = 3*N+2*setup.delta;
%       [K,~,~] = getK_Marmousi(2^topLevel-setup.delta,setup);
%       size(K)
%       N
%       M
%       K_vec = reshape(K,[N*M,1]);
%     end
    
    for level=topLevel:-1:minLevel

        display(['Building matrices for level = ',num2str(level)])
        
        n=2^level-setup.delta; % grid points per axis on current level
        N=2^(level-1)-setup.delta; % grid point per axis on next level down
        
        % if we are on the unit cube, we have n x n grid points.   But if
        % we are on the rectangle [0,9] x [0,3], we have 
        % m x n, where m = 3*n+2 (vertex centered) or m = 3*n
        % (cell-centered)
        
        if strcmp(setup.coefficients,'Marmousi')        
            m = 3*n+2*setup.delta;
            M = 3*N+2*setup.delta;            
        else
            
            m=n;
            M=N;
        end
        

        h = setup.domainHeight/(n+setup.delta); % mesh spacing on the current level
        
        % first select the 1D restriction operator, which is full weighting
        % for vertex-centered multigrid and the scaled transpose of
        % piecewise-constant prolongation for cell-centered.
        
        if strcmp(setup.type,'vertex-centered')
            R_1d_n = FW1D(n);
            R_1d_m = FW1D(m);
%             I_1d_n = INJ1D(n);
%             I_1d_m = INJ1D(m);
        elseif strcmp(setup.type,'cell-centered')
            R_1d_n = 0.5*PC1D(n)';
            R_1d_m = 0.5*PC1D(m)';
%             I_1d_n = INJ1D(n);
%             I_1d_m = INJ1D(m);
        else
            error('invalid setup type')
        end
        
        % now we use Kronecker products to build the d-dimensional
        % restriction operators.  Only d=2 and d=3 are supported.
        % Also, rectangular domains are currently only supported in 2D, in
        % the context of Marmousi.
        
        if d==2        
            I_Hh = kron(R_1d_m,R_1d_n);
            %I_Hh = kron(R_1d_n,R_1d_m);
            %Inj = kron(I_1d_m,I_1d_n);
        elseif d==3
            I_Hh = kron(R_1d_n,kron(R_1d_n,R_1d_n));
        else
            error('invalid dimension')
        end

        % now build prolongation as the scaled transpose of restriction.
        % The scaling is the same regardless of whether we use vertex- or
        % cell-centered multigrid.
        
        I_hH = 2^d*I_Hh';

        % next, build the current system matrix L_h.  If we are on the top
        % level or using vertex-centered multigrid, we apply a direct
        % discretization.  We split into a 2nd order part and a 0th order 
        % part 
        
        % L_h = L_2_h+L_0_h.
        
        % This is necessary for cell-centered multigrid, but we do it
        % regardless of which type of multigrid we are using.
        
        if level == topLevel || strcmp(setup.type,'vertex-centered')
            
            if strcmp(setup.coefficients,'constant')
                if d == 2
                    L_2_h = getL_2D(4,-epsilon,-epsilon,-(2-epsilon),-(2-epsilon),n);
                elseif d == 3
                    L_2_h = getL_3D(6,-epsilon,-epsilon,-(3-epsilon)/2,-(3-epsilon)/2,-(3-epsilon)/2,-(3-epsilon)/2,n);
                end
                
                L_0_h = -speye(n^d)*(setup.K*h)^2*(1-1i*setup.alpha);
                
                
            elseif strcmp(setup.coefficients,'variable')
                [L_2_h,L_0_h] = getL_variable(setup,level);
            elseif strcmp(setup.coefficients,'Marmousi') && d==2
                
                [K,~,~] = getK_Marmousi(n,setup);
                K_vec = reshape(K,[n*m,1]);
                
                K_diag = spdiag(K_vec);
%                 K_vec = Inj*K_vec;
                
                L_2_h = getL_2D_rect(4,-1,-1,-1,-1,n,m);
                L_0_h = -K_diag.^2*h^2*(1-1i*setup.alpha);
                
            else
                error('invalid coefficient choice')
            end
            
        % if we are doing cell-centered multigrid and not on the top level,
        % we define the 0th order and 2nd order parts of the new operator
        % based on separate galerkin operators (the second order part 
        % incorporates a scaling by 1/2, the 0th order part doesn't.
        elseif strcmp(setup.type,'cell-centered')
            
            L_2_h = 0.5*Rs{level+1}*L_2_H*Ps{level+1};
            L_0_h = Rs{level+1}*L_0_H*Ps{level+1};
            
        end
            
        L_h = L_2_h+L_0_h;
        
        Ls{level}=L_h;
        Ps{level}=I_hH;
        Rs{level}=I_Hh;

        L_2_H = L_2_h;
        L_0_H = L_0_h;

    end