function f = getPointRHS(setup)

    N = 2^(setup.level)-setup.delta;
    h = setup.domainHeight/(N+setup.delta);

    d = setup.dimension;
    
    if ~strcmp(setup.coefficients,'Marmousi')
        x_max = 1;
        y_max = 1;
        if strcmp(setup.type,'vertex-centered')
            x = h:h:1-h;
        elseif strcmp(setup.type,'cell-centered')
            x = h/2:h:1-h/2;
        end

        if d == 2
            [X,Y]=meshgrid(x);
            delta2 = (X-0.5).^2+(Y-0.5).^2;
        elseif d==3
            [X,Y,Z]=meshgrid(x);
            delta2 = (X-0.5).^2+(Y-0.5).^2+(Z-0.5).^2;
        end
        N_tot = N^d;

    else
       x_max = 9;
       y_max = 3;
       if strcmp(setup.type,'vertex-centered')
            x = h:h:9-h;
            y = h:h:3-h;
        elseif strcmp(setup.type,'cell-centered')
            x = h/2:h:9-h/2;
            y = h/2:h:3-h/2;
       end 
        
       [X,Y]=meshgrid(x,y);
       delta2 = (X-4.5).^2+(Y-0.5).^2;
       N_tot = N*(3*N+2*setup.delta);
        
    end
    
    % make a discrete delta function
    sigma = 2;
    F = exp(-0.5*delta2/(sigma^2*h^2))/(sqrt(2*pi)*sigma*h)^2;
    
    % now multiply rhs by h^2.
    f = h^2*reshape(F,[N_tot,1]);
    
    if d==3 && setup.plotSurfaces
        [X,Y,F]=get_F_mid(X,Y,F);
    end
    
    if setup.plotSurfaces
        figure
        surf(X,Y,F,'Edgecolor','None')
        xlabel('x')
        ylabel('y')
        if d==2
            title('point source rhs')
        else
            title('point source rhs (z = 0.5 slice)')
        end
        set(gca,'fontsize',20,'LineWidth',2)
        xlim([0 x_max])
        ylim([0 y_max])
    end
end