function u_h = smooth(L_h,u_h,f_h,level,setup,RB_stuff)


    if strcmp(setup.smoother,'DAMPED-JACOBI')
        
        D = diag(diag(L_h));        
        u_s = D\( (D-L_h)*u_h+f_h);
        
        if strcmp(setup.coefficients,'constant')
        
            w = setup.dampingParameters(level);            
            u_h = w*u_s+(1-w)*u_h;
            
        elseif strcmp(setup.coefficients,'variable') || strcmp(setup.coefficients,'Marmousi')
            W=setup.Ws{level};
            u_h = W*(u_s-u_h)+u_h;
        end
        
    elseif strcmp(setup.smoother,'RB-SOR')

        % this implementation assumes we have already permuted into the
        % red-black coordinate system.
        
        P = RB_stuff{6};
        Pinv = RB_stuff{7};
        
        %P = setup.Perms{level};
        %Pinv = setup.invPerms{level};
        u_h = u_h(P);
        f_h = f_h(P);
        
%         [N_to_the_d,~]=size(L_h);
%         
%         N_r = ceil(N_to_the_d/2);
%         
%         L_rb=L_h(1:N_r,N_r+1:end);
%         L_br=L_h(N_r+1:end,1:N_r);
%         D_r=L_h(1:N_r,1:N_r);
%         D_b=L_h(N_r+1:end,N_r+1:end);
%         
%         D_r=setup.D_rs{level};
%         D_b=setup.D_bs{level};
%         L_rb=setup.L_rbs{level};
%         L_br=setup.L_brs{level};
%         N_r=setup.Nrs{level};
%       
        N_r=RB_stuff{1};
        D_r=RB_stuff{2};
        D_b=RB_stuff{3};
        L_rb=RB_stuff{4};
        L_br=RB_stuff{5};
        
        u_red = u_h(1:N_r);
        u_black = u_h(N_r+1:end);

        f_red = f_h(1:N_r);
        f_black = f_h(N_r+1:end);
        
        if strcmp(setup.coefficients,'constant')
        
            w = setup.dampingParameters(level);            
            % first update red points
        
            u_s_red = D_r\(-L_rb*u_black+f_red);
            u_red = w*u_s_red+(1-w)*u_red;

            % now the black points
        
            u_s_black = D_b\(-L_br*u_red+f_black);
            u_black = w*u_s_black+(1-w)*u_black;
            
        elseif strcmp(setup.coefficients,'variable') || strcmp(setup.coefficients,'Marmousi')
            Wrr=RB_stuff{8};
            Wbb=RB_stuff{9};
            
            % first update red points
        
            u_s_red = D_r\(-L_rb*u_black+f_red);
            u_red = Wrr*(u_s_red-u_red)+u_red;

            % now the black points

            u_s_black = D_b\(-L_br*u_red+f_black);
            u_black = Wbb*(u_s_black-u_black)+u_black;

            
        end
        
        u_h = [u_red;u_black];
        
        u_h = u_h(Pinv);
        
    else
        error('invalid smoother type.  Please enter DAMPED-JACOBI or RB-SOR');
    end
    