function [wR,wC,muR,muC ] = DampedJacobiSmoothing(a,c,c_m)

    % First the optimal complex damping parameter and smoothing factor -
    % this is just Theorem 4.2.

    b1 = 1-2*(c-c_m)/a;
    b2 = 1+2*c/a;
    
    wC = (abs(b1)/b1+abs(b2)/b2)/(abs(b1)+abs(b2));
    muC = abs(b1-b2)/(abs(b1)+abs(b2));
    
    % Now the optimal real damping parameter and smoothing factor - this
    % was omitted from the paper.
    
    % four possible values
    wR1 = real(a)/(real(a)+c_m);
    wR2 = 0;
    wR3 = real(b1)/abs(b1)^2;
    wR4 = real(b2)/abs(b2)^2;
    muR1 = max(abs(1-wR1*b1),abs(1-wR1*b2));
    muR2 = max(abs(1-wR2*b1),abs(1-wR2*b2));
    muR3 = max(abs(1-wR3*b1),abs(1-wR3*b2));
    muR4 = max(abs(1-wR4*b1),abs(1-wR4*b2));
    muR = min([muR1,muR2,muR3,muR4]);
    if muR1 <=muR
        wR = wR1;
    elseif muR2 <=muR
        wR = wR2;
    elseif muR3 <=muR
        wR = wR3;
    elseif muR4 <= muR
        wR = wR4;
    end
   
    