function mu = RBSOR_SmoothingFactor(a,c,c_m,nu,w)

    % High Frequency Part from Theorem 5.3
    
    muH_p = abs(w*(c-c_m)/a+sqrt(1-w+(w*(c-c_m)/a)^2))^2;
    muH_m = abs(w*(c-c_m)/a-sqrt(1-w+(w*(c-c_m)/a)^2))^2;
    
    muH = max([muH_p,muH_m]);
    
    % Low Frequency Part from Theorem 5.4
    
    tol = 1e-5; % tolerance on norm of imaginary part to be considered real.
    
    if nu==1
        
        % quadratic coefficients
        
        a0=1-w;
        a1=(w/a)*(w/2-1);
        a2=w^2/(2*a^2);
        
        % coefficients of cubic for roots
        
        b0 = real(a0*conj(a1));
        b1 = 2*real(a0*conj(a2))+abs(a1)^2;
        b2 = 3*real(a1*conj(a2));
        b3 = 2*abs(a2)^2;
        
        r = roots([b3 b2 b1 b0]);
        
        
    elseif nu==2
        
        % quartic coefficients
        
        a0 = (w^2-2*w+1);
        a1 = -(w/a)*(w^2-3*w+2);
        a2 = 2*(1-w)*(w/a)^2;
        a3 = 0.5*(w-2)*(w/a)^3;
        a4 = 0.5*(w/a)^4;
        
        % coefficients of degree 7 polynomial for roots
        
        b0 = real(a0*conj(a1));
        b1 = 2*real(a0*conj(a2))+abs(a1)^2;
        b2 = 3*real(a0*conj(a3)+a1*conj(a2));
        b3 = 4*real(a0*conj(a4)+a1*conj(a3))+2*abs(a2)^2;
        b4 = 5*real(a1*conj(a4)+a2*conj(a3));
        b5 = 6*real(a2*conj(a4))+3*abs(a3)^2;
        b6 = 7*real(a3*conj(a4));
        b7 = 4*abs(a4)^2;
        
        r = roots([b7 b6 b5 b4 b3 b2 b1 b0]);
        
    else
        
        error('nu should be 1 or 2')
        
    end
    
    X = [0,2*c];
    for j=1:length(r)
        if real(r(j))>0 && real(r(j))<2*c && abs(imag(r(j)))<tol
            X(end+1)=real(r(j));
        end
    end
    
    muL = -inf;
    
    for j=1:length(X)
        
        x=X(j);
        
        if nu==1 && abs(a0+a1*x+a2*x^2)>muL
            muL = abs(a0+a1*x+a2*x^2);
        elseif nu==2 
            if sqrt(abs(a0+a1*x+a2*x^2+a3*x^3+a4*x^4))>muL
                muL = sqrt(abs(a0+a1*x+a2*x^2+a3*x^3+a4*x^4));
            end
        end
        
    end
    
    mu = max([muL,muH]);

    