function [w,mu]=optimalRB_SOR(a,c,c_m,nu,field)

    if strcmp(field,'C') % optimize over the complex numbers
        
        % fmin expects a 2D vector, not a complex number, so we have to do
        % a conversion
        f = @(W)RBSOR_SmoothingFactor(a,c,c_m,nu,W(1)+1i*W(2));
        % use w_ub from Theorem 5.3 as an initial guess
        w_ub = 2/(1+sqrt(1-4*(c-c_m)^2/a^2));
        W_0 = [real(w_ub);imag(w_ub)];

        % we have observed that a small number of iterations is foten enough
        % to yield convergence.  However, just to make sure, we allow a maximum
        % of 1000 iterations.
        
        options = optimset('TolX',1e-8,'MaxFunEvals',1000);
        
        [W,fval] = fminsearch(f,W_0,options);
        w = W(1)+1i*W(2);
        mu = fval;
        
    elseif strcmp(field,'R') % optimize over the reals

        f = @(W)RBSOR_SmoothingFactor(a,c,c_m,nu,W);
        % use w=1 as an initial guess.
        W_0 = 1;

        % we have observed that a small number of iterations is foten enough
        % to yield convergence.  However, just to make sure, we allow a maximum
        % of 1000 iterations.
        options = optimset('TolX',1e-8,'MaxFunEvals',1000);
        [W,fval] = fminsearch(f,W_0,options);
        w = W;
        mu = fval;
        
    end