function S = getS_2g(setup,theta1,theta2,level)

    % somewhat counterintuitively, S_2g is not necessarily the operator on
    % level two.  Hence level is an explicit parameter

    S = zeros(4,4);
    
    
    alpha = [0 1 1 0;
             0 1 0 1];    
         
    if strcmp(setup.smoother,'RB-SOR')
        
        % for RB-SOR, we only need alpha(1) and alpha(3), since getS
        % returns a 2x2 matrix already incorporating
        % alpha(2) and alpha(4)
        
        for l=0:1

            % this indexing is intended to only give us the 1st and 3rd
            % entrees.
            
            k = 1+2*l;
            
            alphaX = alpha(1,k);
            alphaY = alpha(2,k);

            theta1p = theta1-(alphaX*mod_sign(theta1))*pi;
            theta2p = theta2-(alphaY*mod_sign(theta2))*pi;

            S(k:k+1,k:k+1)=getS(setup,level,theta1p,theta2p);

        end
    
    elseif strcmp(setup.smoother,'damped-Jacobi')
        
        % in this case we need all of the alphas, as getS returns a scalar
        
        for l=1:4
        
            alphaX = alpha(1,l);
            alphaY = alpha(2,l);

            theta1p = theta1-(alphaX*mod_sign(theta1))*pi;
            theta2p = theta2-(alphaY*mod_sign(theta2))*pi;

            S(l,l)=getS(setup,level,theta1p,theta2p);
        
        end
        
    end
        
    