
% This file will allow you to reproduce results from the 3D constant-coefficient
% Experiment in Section 6.4 of the paper.  An appropriate "setup" object is created
% and passed into "Multigrid.m".  Type "help Multigrid" for an explanation
% of what the parameters of the setup object do.  
%
% We fix the strategy as 'opt-complex' for this experiment, but you can try
% others.
%
% Note that you do not need the universal lookup table to run this
% experiment.

clear all;
close all;

% setup.strategy must be one of 
%
% 1. opt-complex
% 2. opt-real
% 3. baseline
% 4. scan
% 5. two-grid
% 6. omega_ub
%
% Type "Help dampingParameterStrategyExperiment" in the command line to
% find out in detail what these options do.

setup.strategy='opt-complex';

% setup.coefficients must be one of "constant", "variable", or "Marmousi".
% For this experiment, we use constant coefficients.

setup.coefficients = 'constant';

% rhs should be 'random' or 'point_source'.  We reported 'random' in the
% paper, but you can also try out 'point_source'.

setup.rhs = 'random';

% for a random RHS we average over 10 iterations.  But feel free to change
% this.

setup.numRandomIt=10;

% type should be 'vertex-centered' or 'cell-centered'.  We reported the
% former in the paper, but feel free to try the latter.

setup.type = 'vertex-centered'; 

% smoother must be one of 'DAMPED-JACOBI' or 'RB-SOR'.

setup.smoother='RB-SOR';

setup.nu = 1; % for RB-SOR, should be to 1 or 2.  For DAMPED-JACOBI, can be any positive integer.

% we reported results for epsilon = 1, 1/3 and 1/5 in the paper.  But
% you can make epsilon anything in (0,1].

setup.epsilon = 1;

% controls the maximum value that kh will take on (for constant coefficient
% problems, like this one, it is also the value kh takes on everywhere).
% Set to sqrt(epsilon)*pi/5 by default, in order to be as large as possible
% while satisfying the constraint (6.4) in the paper.

setup.kh_M = sqrt(setup.epsilon)*pi/5;

% the amount of damping - set to 0.5 by default.

setup.alpha = 0.5;

% the dimension must be two or three.  We reported the case d=3 in the
% paper, but this experiment can also be run with d=2.

setup.dimension = 3;

% The grid has N = 2^level - delta interior grid cells along each
% dimension.  For vertex-centered multigrid, delta = 1.  For cell-centered,
% delta = 0.

% in the paper, we tried level = 6,7,8 and compared convergence rates,
% runtimes, etc.  You can try a bigger level if you want, but be prepared
% to wait for a long time.

setup.level = 6;

% if set to one, multigrid will plot the rhs and the solution (in the 2D
% case - in the 3D case it will plot a representative slice).  If set to
% zero, multigrid will not do this.

setup.plotSurfaces = 1;

% since we are dealing with a damped wave equation, typically only a 
% few wavelengths are visible.  One way to combat this is to raise the
% solution to the power of a number close to zero, counteracting the decay
% of the waves and making more wavelengths visible.

setup.increaseWaveVisibility=0;

[u,res_vec]=Multigrid(setup);